package net.thunderbird.feature.notification.testing.fake.icon

import net.thunderbird.feature.notification.api.ui.icon.SystemNotificationIcon

actual val EMPTY_SYSTEM_NOTIFICATION_ICON: SystemNotificationIcon = 0
